@@ -39,6 +39,7 @@ extern "C" {
 
 // KDE
 #include <kdebug.h>
+#include <klocale.h>
 
 // Exiv2
 #include <exiv2/exif.hpp>
@@ -108,6 +109,7 @@ struct JpegContent::Private {
 	bool mPendingTransformation;
 	QMatrix mTransformMatrix;
 	Exiv2::ExifData mExifData;
+	QString mErrorString;
 
 	Private() {
 		mPendingTransformation = false;
@@ -501,7 +503,7 @@ void JpegContent::applyPendingTransformation() {
 QImage JpegContent::thumbnail() const {
 	QImage image;
 	if (!d->mExifData.empty()) {
-#if (EXIV2_TEST_VERSION(0,17,91))
+#if(EXIV2_TEST_VERSION(0,17,91))
         Exiv2::ExifThumbC thumb(d->mExifData);
         Exiv2::DataBuf thumbnail = thumb.copy();
 #else
@@ -526,6 +528,7 @@ void JpegContent::setThumbnail(const QImage& thumbnail) {
 		kError() << "Could not write thumbnail\n";
 		return;
 	}
+	
 #if (EXIV2_TEST_VERSION(0,17,91))
     Exiv2::ExifThumb thumb(d->mExifData);
     thumb.setJpegThumbnail((unsigned char*)array.data(), array.size());
@@ -538,7 +541,7 @@ void JpegContent::setThumbnail(const QImage& thumbnail) {
 bool JpegContent::save(const QString& path) {
 	QFile file(path);
 	if (!file.open(QIODevice::WriteOnly)) {
-		kError() << "Could not open '" << path << "' for writing\n";
+		d->mErrorString = i18nc("@info", "Could not open file for writing.");
 		return false;
 	}
 
@@ -548,7 +551,7 @@ bool JpegContent::save(const QString& path) {
 
 bool JpegContent::save(QIODevice* device) {
 	if (d->mRawData.size()==0) {
-		kError() << "No data to store\n";
+		d->mErrorString = i18nc("@info", "No data to store.");
 		return false;
 	}
 
@@ -578,4 +581,9 @@ bool JpegContent::save(QIODevice* device) {
 }
 
 
+QString JpegContent::errorString() const {
+	return d->mErrorString;
+}
+
+
 } // namespace
