@@ -1199,6 +1199,7 @@ static const char  *static_camera_list[] =
 "Nikon D2X",
 "Nikon D2Xs",
 "Nikon D3",
+"Nikon D3X",
 "Nikon D40",
 "Nikon D40X",
 "Nikon D50",
@@ -1284,6 +1285,7 @@ static const char  *static_camera_list[] =
 "Pentax K100D",
 "Pentax K100D Super",
 "Pentax K200D",
+"Pentax K2000/K-m",
 "Pentax Optio S",
 "Pentax Optio S4",
 "Pentax Optio 33WR",
