@@ -1,6 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-5 by Enrico Ros <eros.kde@email.it>                *
  *   Copyright (C) 2005   by Piotr Szymanski <niedakh@gmail.com>           *
+ *   Copyright (C) 2008   by Albert Astals Cid <aacid@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -30,6 +31,7 @@
     K_PLUGIN_FACTORY( classname ## Factory, registerPlugin< classname >(); ) \
     K_EXPORT_PLUGIN( classname ## Factory( aboutdata ) )
 
+class QByteArray;
 class QMutex;
 class QPrinter;
 class QPrintDialog;
@@ -43,6 +45,7 @@ class DocumentInfo;
 class DocumentSynopsis;
 class EmbeddedFile;
 class ExportFormatPrivate;
+class FontInfo;
 class GeneratorPrivate;
 class Page;
 class PixmapRequest;
@@ -140,7 +143,9 @@ class OKULAR_EXPORT ExportFormat
         enum StandardExportFormat
         {
             PlainText,         ///< Plain text
-            PDF                ///< PDF, aka Portable Document Format
+            PDF,               ///< PDF, aka Portable Document Format
+            OpenDocumentText,  ///< OpenDocument Text format @since 0.8 (KDE 4.2)
+            HTML   ///< OpenDocument Text format @since 0.8 (KDE 4.2)
         };
 
         /**
@@ -448,6 +453,14 @@ class OKULAR_EXPORT Generator : public QObject
          */
         void updatePageBoundingBox( int page, const NormalizedRect & boundingBox );
 
+    protected Q_SLOTS:
+        /**
+         * Gets the font data for the given font
+         *
+         * @since 0.8 (KDE 4.1)
+         */
+        void requestFontData(const Okular::FontInfo &font, QByteArray *data);
+
     protected:
         /// @cond PRIVATE
         Generator( GeneratorPrivate &dd, QObject *parent, const QVariantList &args );
@@ -455,6 +468,7 @@ class OKULAR_EXPORT Generator : public QObject
         GeneratorPrivate *d_ptr;
 
         friend class Document;
+        friend class DocumentPrivate;
         /// @endcond PRIVATE
 
     private:
